==> nextcloud-app-tasks-0.9.6-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/sk.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Úlohy",
    "Due yesterday" : "Do včera",
    "Due today" : "Do dnes",
    "Due tomorrow" : "Do zajtra",
    "Due on" : "Do",
    "Started yesterday" : "Začala včera",
    "Starts today" : "Začína dnes",
    "Starts tomorrow" : "Začína zajtra",
    "Started on" : "Začala",
    "Starts on" : "Začne",
    "[Remind me yesterday at ]HH:mm" : "[Pripomenuté včera o ]HH:mm",
    "[Remind me today at ]HH:mm" : "[Pripomenúť mi dnes o ]HH:mm",
    "[Remind me tomorrow at ]HH:mm" : "[Pripomenúť mi zajtra o ]HH:mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[Pripomenúť mi ]MMM DD, YYYY,[ o ]HH:mm",
    "Yesterday" : "Včera",
    "Today" : "Dnes",
    "Tomorrow" : "Zajtra",
    "in %s" : "v %s",
    "%s ago" : "%s pred",
    "seconds" : "sekúnd",
    "a minute" : "o minútu",
    "%d minutes" : "%d minút",
    "an hour" : "o hodinu",
    "%d hours" : "%d hodín",
    "a day" : "o deň",
    "%d days" : "%d dní",
    "a month" : "o mesiac",
    "%d months" : "%d mesiacov",
    "a year" : "o rok",
    "%d years" : "%d rokov",
    "week" : "týždeň",
    "weeks" : "týždňov",
    "day" : "deň",
    "days" : "dni",
    "hour" : "hodina",
    "hours" : "hodín",
    "minute" : "minúta",
    "minutes" : "minút",
    "second" : "druhý",
    "before beginning" : "pred začiatkom",
    "after beginning" : "po začiatku",
    "before end" : "pred ukončením",
    "after end" : "po ukončení",
    "Comment" : "Komentár",
    "Add a comment" : "Pridať komentár",
    "This will delete the Calendar \"%s\" and all of its entries." : "Táto operácia odstráni kalendár \"%s\" a všetky jeho položky.",
    "The name \"%s\" is already used." : "Názov \"%s\" je už použitý.",
    "An empty name is not allowed." : "Prázdny názov nie je povolený",
    "Hidden" : "Skryté",
    "Visible" : "Viditeľné",
    "Automatic" : "Automaticky",
    "Sunday" : "Nedeľa",
    "Monday" : "Pondelok",
    "Tuesday" : "Utorok",
    "Wednesday" : "Streda",
    "Thursday" : "Štvrtok",
    "Friday" : "Piatok",
    "Saturday" : "Sobota",
    "Add an important item in \"%s\"..." : "Pridať dôležitú položku do \"%s\"...",
    "Add an item due today in \"%s\"..." : "Pridať položku do dnes do \"%s\"...",
    "Add an item in \"%s\"..." : "Pridať položku do \"%s\"...",
    "Add a current item in \"%s\"..." : "Pridať túto položku do \"%s\"...",
    "Add a subtask to \"%s\"..." : "Pridať podúlohu do „%s“...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n dokončená úloha","%n dokončené úlohy","%n dokončených úloh"],
    "Hours" : "Hodín",
    "Minutes" : "Minút",
    "Set due date" : "Nastaviť do dátumu",
    "%s %% completed" : "%s %% ukončené",
    "priority %s: " : "priorita %s: ",
    "high" : "vysoká",
    "medium" : "stredná",
    "low" : "nízka",
    "no priority assigned" : "nepridelená žiadna priorita",
    "Remind me" : "Pripomenúť mi",
    "at the end" : "na konci",
    "at the beginning" : "na začiatku",
    "Set start date" : "Nastaviť dátum začatia",
    "{calendar} shared by {owner}" : "{calendar} sprístupňuje {owner}",
    "Unnamed" : "nepomenovaný",
    "Important" : "Dôležité",
    "Week" : "Týždeň",
    "All" : "Všetky",
    "Current" : "Aktuálne",
    "Completed" : "Dokončené",
    "Delete" : "Zmazať",
    "Cancel" : "Zrušiť",
    "Edit" : "Upraviť",
    "Link" : "Odkaz",
    "Download" : "Sťahovanie",
    "Save" : "Uložiť",
    "Add List..." : "Pridať zoznam",
    "New List" : "Nový zoznam",
    "Settings" : "Nastavenia",
    "Start of week" : "Začiatok týždňa",
    "Visibility of Smart Collections" : "Viditeľnosť inteligentných kolekcií",
    "Change sort order" : "Zmeniť spôsob zoradenia",
    "Default" : "Predvolené",
    "Due date" : "Dátum ukončenia",
    "Start date" : "Dátum začatia",
    "Priority" : "Priorita",
    "Alphabetically" : "Abecedne",
    "Manually" : "Manuálne",
    "Load remaining completed tasks." : "Načítať zostávajúce dokončené úlohy.",
    "Task is completed" : "Úloha je dokončená",
    "All day" : "Celý deň",
    "(New category)" : "(Nová kategória)",
    "Select categories..." : "Vybrať kategórie...",
    "Loading the task..." : "Nahrávam úlohu...",
    "Task not found!" : "Úloha nebola nájdená!",
    "add a subtask to" : "pridať podúlohu do",
    "Toggle subtasks" : "Prepínanie podúloh",
    "Toggle completed subtasks" : "Prepnúť dokončené podúlohy"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");

==> nextcloud-app-tasks-0.9.7-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/sk.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Úlohy",
    "Due yesterday" : "Do včera",
    "Due today" : "Do dnes",
    "Due tomorrow" : "Do zajtra",
    "Due on" : "Do",
    "Started yesterday" : "Začala včera",
    "Starts today" : "Začína dnes",
    "Starts tomorrow" : "Začína zajtra",
    "Started on" : "Začala",
    "Starts on" : "Začne",
    "[Remind me yesterday at ]HH:mm" : "[Pripomenuté včera o ]HH:mm",
    "[Remind me today at ]HH:mm" : "[Pripomenúť mi dnes o ]HH:mm",
    "[Remind me tomorrow at ]HH:mm" : "[Pripomenúť mi zajtra o ]HH:mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[Pripomenúť mi ]MMM DD, YYYY,[ o ]HH:mm",
    "Yesterday" : "Včera",
    "Today" : "Dnes",
    "Tomorrow" : "Zajtra",
    "in %s" : "v %s",
    "%s ago" : "%s pred",
    "seconds" : "sekúnd",
    "a minute" : "o minútu",
    "%d minutes" : "%d minút",
    "an hour" : "o hodinu",
    "%d hours" : "%d hodín",
    "a day" : "o deň",
    "%d days" : "%d dní",
    "a month" : "o mesiac",
    "%d months" : "%d mesiacov",
    "a year" : "o rok",
    "%d years" : "%d rokov",
    "week" : "týždeň",
    "weeks" : "týždňov",
    "day" : "deň",
    "days" : "dni",
    "hour" : "hodina",
    "hours" : "hodín",
    "minute" : "minúta",
    "minutes" : "minút",
    "second" : "druhý",
    "before beginning" : "pred začiatkom",
    "after beginning" : "po začiatku",
    "before end" : "pred ukončením",
    "after end" : "po ukončení",
    "Comment" : "Komentár",
    "Add a comment" : "Pridať komentár",
    "This will delete the Calendar \"%s\" and all of its entries." : "Táto operácia odstráni kalendár \"%s\" a všetky jeho položky.",
    "The name \"%s\" is already used." : "Názov \"%s\" je už použitý.",
    "An empty name is not allowed." : "Prázdny názov nie je povolený",
    "Hidden" : "Skryté",
    "Visible" : "Viditeľné",
    "Automatic" : "Automaticky",
    "Sunday" : "Nedeľa",
    "Monday" : "Pondelok",
    "Tuesday" : "Utorok",
    "Wednesday" : "Streda",
    "Thursday" : "Štvrtok",
    "Friday" : "Piatok",
    "Saturday" : "Sobota",
    "Add an important item in \"%s\"..." : "Pridať dôležitú položku do \"%s\"...",
    "Add an item due today in \"%s\"..." : "Pridať položku do dnes do \"%s\"...",
    "Add an item in \"%s\"..." : "Pridať položku do \"%s\"...",
    "Add a current item in \"%s\"..." : "Pridať túto položku do \"%s\"...",
    "Add a subtask to \"%s\"..." : "Pridať podúlohu do „%s“...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n dokončená úloha","%n dokončené úlohy","%n dokončených úloh","%n dokončených úloh"],
    "Hours" : "Hodín",
    "Minutes" : "Minút",
    "Set due date" : "Nastaviť do dátumu",
    "%s %% completed" : "%s %% ukončené",
    "priority %s: " : "priorita %s: ",
    "high" : "vysoká",
    "medium" : "stredná",
    "low" : "nízka",
    "no priority assigned" : "nepridelená žiadna priorita",
    "Remind me" : "Pripomenúť mi",
    "at the end" : "na konci",
    "at the beginning" : "na začiatku",
    "Set start date" : "Nastaviť dátum začatia",
    "{calendar} shared by {owner}" : "{calendar} sprístupňuje {owner}",
    "Unnamed" : "nepomenovaný",
    "Important" : "Dôležité",
    "Week" : "Týždeň",
    "All" : "Všetky",
    "Current" : "Aktuálne",
    "Completed" : "Dokončené",
    "Delete" : "Zmazať",
    "Cancel" : "Zrušiť",
    "Edit" : "Upraviť",
    "Link" : "Odkaz",
    "Download" : "Sťahovanie",
    "Save" : "Uložiť",
    "Add List..." : "Pridať zoznam",
    "New List" : "Nový zoznam",
    "Settings" : "Nastavenia",
    "Start of week" : "Začiatok týždňa",
    "Visibility of Smart Collections" : "Viditeľnosť inteligentných kolekcií",
    "Change sort order" : "Zmeniť spôsob zoradenia",
    "Default" : "Predvolené",
    "Due date" : "Dátum ukončenia",
    "Start date" : "Dátum začatia",
    "Priority" : "Priorita",
    "Alphabetically" : "Abecedne",
    "Manually" : "Manuálne",
    "Load remaining completed tasks." : "Načítať zostávajúce dokončené úlohy.",
    "Task is completed" : "Úloha je dokončená",
    "All day" : "Celý deň",
    "(New category)" : "(Nová kategória)",
    "Select categories..." : "Vybrať kategórie...",
    "Loading the task..." : "Nahrávam úlohu...",
    "Task not found!" : "Úloha nebola nájdená!",
    "add a subtask to" : "pridať podúlohu do",
    "Toggle subtasks" : "Prepínanie podúloh",
    "Toggle completed subtasks" : "Prepnúť dokončené podúlohy"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
